<?php

namespace Drupal\show_as_expanded_always;

/**
 * Class ShowAsExpandedAlwaysManager that checks and sets the expanded field.
 *
 * @package Drupal\show_as_expanded_always
 */
class ShowAsExpandedAlwaysManager {

  /**
   * Set the default value of "show as expanded" - checkbox to true.
   *
   * @param array $form
   *   The current form.
   * @param string $formId
   *   The id of the form.
   * @param string $currentPath
   *   The current path.
   */
  public function activateShowAsExpandedField(array &$form, $formId, $currentPath) {
    if ('menu_link_content_menu_link_content_form' === $formId
      && $this->endsWith($currentPath, '/add')) {
      if (isset($form['expanded']['widget']['value']['#default_value'])) {
        $form['expanded']['widget']['value']['#default_value'] = TRUE;
      }
    }

  }

  /**
   * Check if string $haystack with a string $needle.
   *
   * @param string $haystack
   *   The string that should contain the needle.
   * @param string $needle
   *   The string that is searched in the haystack.
   *
   * @return bool
   *   True if the $haystack ends with $needle.
   */
  protected function endsWith($haystack, $needle) {
    $length = strlen($needle);
    if ($length == 0) {
      return TRUE;
    }

    return (substr($haystack, -$length) === $needle);

  }

}
